# Python Sugar Activity Application Wrapper for fldigi
# (fldigi specific strings are in _gotClicked routine)
# Assumes $PATH includes activityBundle/bin, which holds fldigi
# Assumes suitable conf file and font directory are in activityBundle/info
# Derived from HelloWorldActivity.py, see further comments at bottom
# based on http://olpcnews.com/forum/index.php?topic=863.msg13662#msg13662

from sugar.activity import activity
import gtk, logging, os, os.path, subprocess, sys

class FldigiActivity(activity.Activity): # exec = sugar-activity FldigiActivity.FldigiActivity in activity.info
    def __init__(self, handle):
        #print "starting __init__", handle, sys.argv, os.environ # could print to log
        self._debug = True
        self._name = os.environ['SUGAR_BUNDLE_NAME'] # take name from activity
        self._logger = logging.getLogger(self._name)
        if self._debug:
            self._logger.setLevel(logging.DEBUG)
        self._startupLogging()
        activity.Activity.__init__(self, handle) # super class does real work
        self._logger.debug("activity running")
        self._displaySetup()
        self._logger.info("__init__ done")

    def _displaySetup(self): # can custimize
        self.set_title(self._name)
        # Create Toolbox, contains Activity Toolbar, includes Close button
        toolbox = activity.ActivityToolbox(self)
        self.set_toolbox(toolbox)
        toolbox.show()
        # minimal pygtk gui
        self.button = gtk.Button('Click to start ' + self._name)
        self.button.connect("clicked", self._gotClicked, None)
        self.set_canvas(self.button)
        self.button.show()

    def _gotClicked(self, widget, data=None): # must customize for application
        self._logger.info('gotClicked() start')
        infoDir = os.path.join(os.environ['SUGAR_BUNDLE_PATH'], "info")
        confFile = os.path.join(infoDir, "conf")
        fontFile = os.path.join(infoDir, "font-arial-24-iso-8859-1/font.desc")
        os.putenv('LD_LIBRARY_PATH', os.path.join(os.environ['SUGAR_BUNDLE_PATH'], "lib"))
        retcod = subprocess.call(["fldigi"])
        self._logger.info('fldigi returned:' + str(retcod))

    def _startupLogging(self):
        self._logger.info('Environment includes:')
        self._logger.info(os.environ['SUGAR_BUNDLE_PATH'])
        if self._logger.isEnabledFor(logging.DEBUG):
            self._logger.debug(os.environ['SUGAR_ACTIVITY_ROOT'])
            self._logger.debug(os.environ['SUGAR_BUNDLE_ID'])
            self._logger.debug(os.environ['HOME'])
            #self._logger.debug(os.environ['TMPDIR'])
            #self._logger.debug(os.environ['USER'])
            self._logger.debug(os.environ['DBUS_SESSION_BUS_ADDRESS'])

# needs gui & routines to find / pick media files

# for Sugar Activity Bundle info see
#  http://wiki.laptop.org/go/Activity_bundles
#  http://wiki.laptop.org/go/Sugar_Activity_Tutorial -- HelloWorldActivity.py
#  http://www.ibm.com/developerworks/linux/library/l-sugar-olpc
# for PyGTK info see http://www.pygtk.org/, http://www.pygtk.org/pygtk2tutorial/index.html

# following may be of future interest
#  import sugar.env
#  profile_path = sugar.env.get_profile_path() #where to save activity prefs
#  log_path = sugar.env.get_logs_path() #for cleanup, but not possible now
#  /usr/share/activities/Log.activity/logviewer.py for file display in pygtk
 
